#/* Copyright 1998-2011 Research Foundation State University of New York */
#
#/* This file is part of QuB.                                            */
#
#/* QuB is free software; you can redistribute it and/or modify          */
#/* it under the terms of the GNU General Public License as published by */
#/* the Free Software Foundation, either version 3 of the License, or    */
#/* (at your option) any later version.                                  */
#
#/* QuB is distributed in the hope that it will be useful,               */
#/* but WITHOUT ANY WARRANTY; without even the implied warranty of       */
#/* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        */
#/* GNU General Public License for more details.                         */
#
#/* You should have received a copy of the GNU General Public License,   */
#/* named LICENSE.txt, in the QuB program directory.  If not, see        */
#/* <http://www.gnu.org/licenses/>.                                      */

# Adds the FindNotes (a.k.a. FNote) button which searches a specified 
# folder for data notes containing specified text.
import os
import os.path
import re
import string
import qubtree
import QUB
from Buttons import *

def SearchDataNotes(path, pattern, isRegexp, subfolders):
    repattern = re.compile(pattern)
    for root, dirs, files in os.walk(path):
        if not subfolders:
            del dirs[:]
        for name in [fname for fname in files if re.search('.qsf$', fname)]:
            sess = qubtree.Open(name, 1)
            notes = str(sess.find('Comment').data)
            name = name[:len(name)-4] + str(sess.find('FileExt').data)
            del sess

            if (isRegexp and repattern.search(notes)
            or (notes.find(pattern) >= 0)):
                yield root + name


def ReportDataNotes(props):
    path = props['path']
    pattern = props['pattern']
    isRegexp = props['isRegexp'] == 'yes'
    subfolders = props['subfolders'] == 'yes'

    QUB.Report('Searching for data notes containing "' + pattern + '" ...')

    for fname in SearchDataNotes(path, pattern, isRegexp, subfolders):
        QUB.Report(' > ' + fname)

    QUB.Report('... done searching')        


AddTaskButton('FindNotes', ReportDataNotes, 'FNote', 1, 1,
                      'Find data with "Data Notes" containing ...', '',
                      'FindNotes properties:',
                      [TextField("path", "in folder:", "C:\\", acceptString),
                       TextField("pattern", "containing text:", "", acceptString),
                       ChoiceField("isRegexp", "using regular expressions:", ['yes', 'no'], 'no'),
                       ChoiceField("subfolders", "search in sub-folders:", ['yes', 'no'], 'yes')],
                      'Scripts')
